--liquibase formatted sql
--changeset cb:1
CREATE TABLE IF NOT EXISTS
  file_index (
    id BIGSERIAL PRIMARY KEY NOT NULL,
    sha256 bytea NOT NULL CHECK (length(sha256) = 32),
    md5 bytea NOT NULL CHECK (length(md5) = 16),
    size BIGINT NOT NULL,
    date_created TIMESTAMPTZ NOT NULL DEFAULT NOW()
  );

CREATE UNIQUE INDEX IF NOT EXISTS idx_file_sha256 ON file_index (sha256);

CREATE INDEX IF NOT EXISTS idx_file_md5 ON file_index (md5);

CREATE INDEX IF NOT EXISTS idx_file_index_date_created ON file_index (date_created);

--changeset cb:2
CREATE TABLE IF NOT EXISTS
  file_details (
    id BIGSERIAL PRIMARY KEY NOT NULL,
    file_index_id BIGINT NOT NULL REFERENCES file_index (id),
    sha256 bytea NOT NULL CHECK (length(sha256) = 32),
    md5 bytea NOT NULL CHECK (length(md5) = 16),
    s3_key varchar(1024) NOT NULL,
    size BIGINT NOT NULL,
    truncated BOOLEAN NOT NULL DEFAULT FALSE,
    date_created TIMESTAMPTZ NOT NULL DEFAULT NOW(),
    date_modified TIMESTAMPTZ NOT NULL DEFAULT NOW(),
    test BOOLEAN NOT NULL DEFAULT FALSE
  );

CREATE UNIQUE INDEX IF NOT EXISTS idx_file_details_file_index_id ON file_details (file_index_id);

--changeset cb:3
CREATE TABLE IF NOT EXISTS
  cust (
    id BIGSERIAL UNIQUE NOT NULL PRIMARY KEY,
    search_key bytea NOT NULL CHECK (length(search_key) = 32), --should be digest(org_key, 'sha256')
    date_created TIMESTAMPTZ NOT NULL DEFAULT NOW(),
    org_key VARCHAR(128)
  );

CREATE UNIQUE INDEX IF NOT EXISTS idx_cust_search_key ON cust (search_key);

--changeset cb:4
CREATE TABLE IF NOT EXISTS
  file_details_cust_link (
    id BIGSERIAL PRIMARY KEY NOT NULL,
    file_details_id BIGINT NOT NULL REFERENCES file_details (id),
    cust_id BIGINT NOT NULL REFERENCES cust (id),
    date_created TIMESTAMPTZ NOT NULL DEFAULT NOW()
  );

CREATE INDEX IF NOT EXISTS idx_file_details_cust_link_file_details_id ON file_details_cust_link (file_details_id);

CREATE INDEX IF NOT EXISTS idx_file_details_cust_link_cust_id ON file_details_cust_link (cust_id);
